@@ -1,6 +1,6 @@
 /*
  * Argus Software
- * Copyright (c) 2000-2014 QoSient, LLC
+ * Copyright (c) 2000-2016 QoSient, LLC
  * All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -472,7 +472,7 @@ typedef struct {
 #define k_CiscoV9MaxPktLen		26
 #define k_CiscoV9IpV6SrcAddr		27
 #define k_CiscoV9IpV6DstAddr		28
-#define k_CiscoV9IPv6SrcMask		29
+#define k_CiscoV9IPV6SrcMask		29
 #define k_CiscoV9IpV6DstMask		30
 #define k_CiscoV9IpV6FlowLabel		31
 #define k_CiscoV9IpV6IcmpType		32
