@@ -1,6 +1,6 @@
 /*
  * Argus Software
- * Copyright (c) 2000-2014 QoSient, LLC
+ * Copyright (c) 2000-2016 QoSient, LLC
  * All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -20,9 +20,9 @@
  */
 
 /* 
- * $Id: //depot/argus/clients/include/argus_label.h#24 $
- * $DateTime: 2014/05/15 16:19:41 $
- * $Change: 2833 $
+ * $Id: //depot/argus/clients/include/argus_label.h#27 $
+ * $DateTime: 2016/06/01 15:17:28 $
+ * $Change: 3148 $
  */
 
 #ifndef ArgusLabeler_h
@@ -176,7 +176,7 @@ struct ArgusLabelerStruct *ArgusNewLabeler (struct ArgusParserStruct *, int);
 void ArgusDeleteLabeler (struct ArgusParserStruct *, struct ArgusLabelerStruct *);
 
 struct ArgusLabelerStruct *ArgusLabeler = NULL;
-int ArgusLabelRecord (struct ArgusParserStruct *, struct ArgusRecordStruct *);
+struct ArgusRecordStruct *ArgusLabelRecord (struct ArgusParserStruct *, struct ArgusRecordStruct *);
 int ArgusAddToRecordLabel (struct ArgusParserStruct *, struct ArgusRecordStruct *, char *);
 
 
@@ -213,7 +213,7 @@ extern void ArgusDeleteLabeler (struct ArgusParserStruct *, struct ArgusLabelerS
 extern struct ArgusLabelerStruct *ArgusLabeler;
 extern void RaPrintLabelTree (struct ArgusLabelerStruct *, struct RaAddressStruct *, int, int);
 
-extern int ArgusLabelRecord (struct ArgusParserStruct *, struct ArgusRecordStruct *);
+extern struct ArgusRecordStruct *ArgusLabelRecord (struct ArgusParserStruct *, struct ArgusRecordStruct *);
 extern int ArgusAddToRecordLabel (struct ArgusParserStruct *, struct ArgusRecordStruct *, char *);
 
 extern struct RaAddressStruct *RaFindAddress (struct ArgusParserStruct *, struct RaAddressStruct *, struct RaAddressStruct *, int);
